==> nextcloud-app-richdocuments-1.1.25-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/fr.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Enregistrement...",
    "Download this revision" : "Télécharger cette révision",
    "Restore this revision" : "Restaurer cette révision",
    "Latest revision" : "Dernière révision",
    "More versions..." : "Plus de versions...",
    "Just now" : "À l'instant",
    "Failed to revert the document to older version" : "Impossible de restaurer le fichier à son ancienne version",
    "Save" : "Enregistrer",
    "Loading documents..." : "Chargement des documents...",
    "Edit" : "Éditer",
    "View" : "Vue",
    "Document" : "Document",
    "Spreadsheet" : "Feuille de calcul",
    "Presentation" : "Présentation",
    "Could not create file" : "Impossible de créer le fichier",
    "New Document.odt" : "Nouveau Document.odt",
    "New Spreadsheet.ods" : "Nouvelle Feuille de Calcul.ods",
    "New Presentation.odp" : "Nouvelle Présentation.odp",
    "New Document.docx" : "Nouveau Document.docx",
    "New Spreadsheet.xlsx" : "Nouveau Tableur.xlsx",
    "New Presentation.pptx" : "Nouvelle Présentation.pptx",
    "Can't create document" : "Impossible de créer le document",
    "Saved" : "Sauvegardé",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Sauvegardé avec une erreur : Collabora Online devrait utiliser le même protocole que lors de l'installation du serveur.",
    "Collabora Online" : "Collabora en ligne",
    "Collabora Online server" : "Serveur Collabora en ligne",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "Adresse (et port) du serveur Collabora en ligne qui fourni la fonctionnalité d'édition comme un client WOPI.",
    "Apply" : "Appliquer",
    "Use OOXML by default for new files" : "Utiliser le format OOXML par défaut pour les nouveaux fichiers",
    "Wrong password. Please retry." : "Mot de passe erroné. Merci de réessayer.",
    "Password" : "Mot de passe",
    "OK" : "OK",
    "Guest %s" : "Invité %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ce lien a expiré ou n'a jamais existé. Pour plus de détails, veuillez contacter la personne qui a partagé ce lien avec vous."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-richdocuments-1.12.31-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/fr.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Enregistrement...",
    "Download this revision" : "Télécharger cette révision",
    "Restore this revision" : "Restaurer cette révision",
    "Latest revision" : "Dernière révision",
    "More versions..." : "Plus de versions...",
    "Just now" : "À l'instant",
    "Failed to revert the document to older version" : "Impossible de restaurer le fichier à son ancienne version",
    "Save" : "Enregistrer",
    "Loading documents..." : "Chargement des documents...",
    "Edit" : "Éditer",
    "New Document" : "Nouveau document",
    "New Spreadsheet" : "Nouvelle feuille de calcul",
    "New Presentation" : "Nouvelle présentation",
    "Could not create file" : "Impossible de créer le fichier",
    "New Document.odt" : "Nouveau Document.odt",
    "New Spreadsheet.ods" : "Nouvelle Feuille de Calcul.ods",
    "New Presentation.odp" : "Nouvelle Présentation.odp",
    "New Document.docx" : "Nouveau Document.docx",
    "New Spreadsheet.xlsx" : "Nouveau Tableur.xlsx",
    "New Presentation.pptx" : "Nouvelle Présentation.pptx",
    "Can't create document" : "Impossible de créer le document",
    "Saved" : "Sauvegardé",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Sauvegardé avec une erreur : Collabora Online devrait utiliser le même protocole que lors de l'installation du serveur.",
    "Collabora Online" : "Collabora en ligne",
    "Collabora Online server" : "Serveur Collabora en ligne",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "Adresse (et port) du serveur Collabora en ligne qui fourni la fonctionnalité d'édition comme un client WOPI.",
    "Apply" : "Appliquer",
    "Use OOXML by default for new files" : "Utiliser le format OOXML par défaut pour les nouveaux fichiers",
    "Wrong password. Please retry." : "Mot de passe erroné. Merci de réessayer.",
    "Password" : "Mot de passe",
    "OK" : "OK",
    "Guest %s" : "Invité %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ce lien a expiré ou n'a jamais existé. Pour plus de détails, veuillez contacter la personne qui a partagé ce lien avec vous."
},
"nplurals=2; plural=(n > 1);");
